.. DiCE documentation master file, created by
   sphinx-quickstart on Tue May 19 13:15:18 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Getting Started:
   
   readme

.. toctree::
   :maxdepth: 2
   :caption: Notebooks:
   
   notebooks/nb_index

.. toctree::
   :maxdepth: 2
   :caption: Package:

   dice_ml

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
